@@ -20,12 +20,13 @@ import os
 
 try:
     from urllib.parse import urlencode, urlparse
-    from urllib.request import urlopen, Request, unquote
+    from urllib.request import Request, HTTPRedirectHandler, build_opener
     from urllib.error import HTTPError
 except ImportError:
-    from urllib import urlencode, unquote
     from urlparse import urlparse
-    from urllib2 import urlopen, Request, HTTPError
+    from urllib import urlencode
+    from urllib2 import Request, HTTPError
+    from urllib2 import HTTPRedirectHandler, build_opener
 
 
 class MultiProcess(object):
@@ -126,6 +127,31 @@ def multi_package(func, args):
     return zip(itertools.repeat(func), args)
 
 
+class AuthRedirectHandler(HTTPRedirectHandler):
+
+    def redirect_request(self, req, fp, code, msg, headers, newurl):
+        newreq = HTTPRedirectHandler.redirect_request(
+            self, req, fp, code, msg, headers, newurl)
+
+        if 'Authorization' not in req.headers:
+            return newreq
+
+        src = urlparse(req.get_full_url()).hostname
+        dest = urlparse(newreq.get_full_url()).hostname
+
+        if dest != src:
+            bot.debug('AuthRedirectHandler: stripping "Authorization" header '
+                      "(%s != %s)" % (dest, src))
+            del newreq.headers['Authorization']
+
+        return newreq
+
+
+def safe_urlopen(url, data=None):
+    opener = build_opener(AuthRedirectHandler())
+    return opener.open(url, data=data)
+
+
 class ApiConnection(object):
 
     def __init__(self, **kwargs):
@@ -275,7 +301,7 @@ class ApiConnection(object):
         '''
 
         try:
-            response = urlopen(request)
+            response = safe_urlopen(request)
 
         # If we have an HTTPError, try to follow the response
         except HTTPError as error:
@@ -288,7 +314,7 @@ class ApiConnection(object):
                 try:
                     request = self.prepare_request(request.get_full_url(),
                                                    headers=self.headers)
-                    response = urlopen(request)
+                    response = safe_urlopen(request)
                 except HTTPError as error:
                     bot.debug('Http Error with code %s' % (error.code))
                     return error
