@@ -1,4 +1,5 @@
 /* 
+ * Copyright (c) 2017-2018, SyLabs, Inc. All rights reserved.
  * Copyright (c) 2017, SingularityWare, LLC. All rights reserved.
  *
  * Copyright (c) 2015-2017, Gregory M. Kurtzer. All rights reserved.
@@ -55,6 +56,8 @@ int main(int argc, char **argv) {
     char *target_pwd = NULL;
     char *command = NULL;
 
+    fd_cleanup();
+
     singularity_config_init(joinpath(SYSCONFDIR, "/singularity/singularity.conf"));
 
     singularity_priv_init();
@@ -101,7 +104,13 @@ int main(int argc, char **argv) {
     
     singularity_priv_drop_perm();
 
-    if ( singularity_registry_get("CONTAIN") != NULL ) {
+    if ( ( target_pwd = singularity_registry_get("TARGET_PWD") ) != NULL ) {
+        singularity_message(DEBUG, "Attempting to chdir to TARGET_PWD: %s\n", target_pwd);
+        if ( chdir(target_pwd) != 0 ) {
+            singularity_message(ERROR, "Could not change directory to: %s\n", target_pwd);
+            ABORT(255);
+        }
+    } else if ( singularity_registry_get("CONTAIN") != NULL ) { 
         singularity_message(DEBUG, "Attempting to chdir to home: %s\n", singularity_priv_home());
         if ( chdir(singularity_priv_home()) != 0 ) {
             singularity_message(WARNING, "Could not chdir to home: %s\n", singularity_priv_home());
@@ -110,12 +119,6 @@ int main(int argc, char **argv) {
                 ABORT(255);
             }
         }
-    } else if ( ( target_pwd = singularity_registry_get("TARGET_PWD") ) != NULL ) {
-        singularity_message(DEBUG, "Attempting to chdir to TARGET_PWD: %s\n", target_pwd);
-        if ( chdir(target_pwd) != 0 ) {
-            singularity_message(ERROR, "Could not change directory to: %s\n", target_pwd);
-            ABORT(255);
-        }
     } else if ( pwd != NULL ) {
         singularity_message(DEBUG, "Attempting to chdir to CWD: %s\n", pwd);
         if ( chdir(pwd) != 0 ) {
