@@ -1,4 +1,5 @@
 /* 
+ * Copyright (c) 2017-2018, SyLabs, Inc. All rights reserved.
  * Copyright (c) 2017, SingularityWare, LLC. All rights reserved.
  *
  * Copyright (c) 2015-2017, Gregory M. Kurtzer. All rights reserved.
@@ -131,7 +132,6 @@ int _singularity_runtime_mount_binds(void) {
             }
         }
 
-        singularity_priv_escalate();
         singularity_message(VERBOSE, "Binding '%s' to '%s/%s'\n", source, container_dir, dest);
         if ( singularity_mount(source, joinpath(container_dir, dest), NULL, MS_BIND|MS_NOSUID|MS_NODEV|MS_REC, NULL) < 0 ) {
             singularity_message(ERROR, "There was an error binding the path %s: %s\n", source, strerror(errno));
@@ -143,7 +143,6 @@ int _singularity_runtime_mount_binds(void) {
                 ABORT(255);
             }
         }
-        singularity_priv_drop();
     }
 
     return(0);
